@@ -13,6 +13,7 @@ BEGIN {
     my @delete_env_keys = qw(
         DEVEL_COVER_OPTIONS
         MODULEBUILDRC
+        PERL_MB_OPT
         HARNESS_TIMER
         HARNESS_OPTIONS
         HARNESS_VERBOSE
@@ -155,7 +156,7 @@ sub stdout_stderr_of {
   $stdout = stdout_of ( sub {
       $stderr = stderr_of( $subr )
   });
-  return ($stdout, $stderr);
+  return wantarray ? ($stdout, $stderr) : $stdout . $stderr;
 }
 
 sub slurp {
